@@ -2,7 +2,7 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -285,6 +285,16 @@ things.
                 type       => 'leaf',
                 value_type => 'string'
             },
+            [qw/a_very_long_string/] => {
+                type       => 'leaf',
+                value_type => 'string',
+                default => "    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU Lesser General Public License as
+    published by the Free Software Foundation; either version 2.1 of the
+    License, or (at your option) any later version.
+    On Debian GNU/Linux systems, the complete text of version 2.1 of the GNU
+    Lesser General Public License can be found in `/usr/share/common-licenses/LGPL-2.1'"
+            },
             [qw/a_mandatory_string another_mandatory_string/] => {
                 type       => 'leaf',
                 mandatory  => 1,
@@ -341,6 +351,29 @@ things.
                 summary => 'will checklist be served ? ;-) ',
             },
 
+            'check_list_with_upstream_default', => {
+                # from OpenSsh Ssh model (KexAlgorithms)
+                'choice' => [
+                    'ecdh-sha2-nistp256',
+                    'ecdh-sha2-nistp384',
+                    'ecdh-sha2-nistp521',
+                    'diffie-hellman-group-exchange-sha256',
+                    'diffie-hellman-group-exchange-sha1',
+                    'diffie-hellman-group14-sha1',
+                    'diffie-hellman-group1-sha1'
+                ],
+                'description' => 'Specifies the available KEX (Key Exchange) algorithms.',
+                'type' => 'check_list',
+                'upstream_default_list' => [
+                    'diffie-hellman-group-exchange-sha1',
+                    'diffie-hellman-group-exchange-sha256',
+                    'diffie-hellman-group1-sha1',
+                    'diffie-hellman-group14-sha1',
+                    'ecdh-sha2-nistp256',
+                    'ecdh-sha2-nistp384',
+                    'ecdh-sha2-nistp521'
+                ]
+            },
             my_reference => {
                 type       => 'leaf',
                 value_type => 'reference',
